@@ -1,6 +1,5 @@
 CHROMEDRIVER_CHROMIUM_URL = 'https://chromedriver.chromium.org'
 CHROMEDRIVER_STORAGE_URL = 'https://chromedriver.storage.googleapis.com'
-LATEST_RELEASE_URL = CHROMEDRIVER_STORAGE_URL + 'LATEST_RELEASE'
 
 ZIP_TYPE = '.zip'
 
@@ -8,7 +7,7 @@ CHROMEDRIVER = 'chromedriver'
 FILE_NAME_CHROMEDRIVER = 'chromedriver'
 FILE_NAME_CHROMEDRIVER_EXE = 'chromedriver.exe'
 
-UL_RELEASES_SELECTOR = '#sites-canvas-main-content > table > tbody > tr > td > div > div:nth-child(5) > ul'
+UL_VERSIONS_SELECTOR = '#sites-canvas-main-content > table > tbody > tr > td > div > div:nth-child(5) > ul'
 
-LATEST_STABLE_RELEASE_STR = 'Latest stable release'
-LATEST_BETA_RELEASE_STR = 'Latest beta release'
+LATEST_STABLE_VERSION_STR = 'Latest stable release'
+LATEST_BETA_VERSION_STR = 'Latest beta release'
