@@ -14,11 +14,11 @@ from requests.exceptions import HTTPError
 from . import constants
 from . import retriever
 from .platforms import Platforms
-from .phase import Phase
+from .phases import Phases
 from .exceptions import GetChromeDriverError
 from .exceptions import UnknownPlatformError
-from .exceptions import ReleaseUrlError
-from .exceptions import UnknownReleaseError
+from .exceptions import VersionUrlError
+from .exceptions import UnknownVersionError
 from .exceptions import DownloadError
 from .exceptions import VersionError
 
@@ -38,20 +38,20 @@ class GetChromeDriver:
         else:
             self.__platform = self.__check_platform(platform)
 
-        self.__phases = Phase()
+        self.__phases = Phases()
 
-    def stable_release_version(self) -> str:
-        """ Return the latest stable release version """
+    def stable_version(self) -> str:
+        """ Return the latest stable version """
 
-        return self.__latest_release_version('stable')
+        return self.__latest_version_by_phase('stable')
 
-    def beta_release_version(self) -> str:
-        """ Return the latest beta release version """
+    def beta_version(self) -> str:
+        """ Return the latest beta version """
 
-        return self.__latest_release_version('beta')
+        return self.__latest_version_by_phase('beta')
 
-    def __latest_release_version(self, phase) -> str:
-        """ Return the stable or beta release version """
+    def __latest_version_by_phase(self, phase) -> str:
+        """ Return the latest stable or latest beta version """
 
         res = requests.get(constants.CHROMEDRIVER_CHROMIUM_URL)
 
@@ -59,156 +59,148 @@ class GetChromeDriver:
             raise GetChromeDriverError('error: could not connect to ' + constants.CHROMEDRIVER_CHROMIUM_URL)
 
         soup = BeautifulSoup(res.content, 'html.parser')
-        ul = soup.select_one(constants.UL_RELEASES_SELECTOR)
+        ul = soup.select_one(constants.UL_VERSIONS_SELECTOR)
         for li in ul:
             li_text = li.text.replace(u'\u00A0', ' ')
             if self.__phases.stable == phase:
-                release_str = constants.LATEST_STABLE_RELEASE_STR
+                version_str = constants.LATEST_STABLE_VERSION_STR
             else:
-                release_str = constants.LATEST_BETA_RELEASE_STR
+                version_str = constants.LATEST_BETA_VERSION_STR
 
-            if li_text[:len(release_str)].lower() == release_str.lower():
+            if li_text[:len(version_str)].lower() == version_str.lower():
                 try:
-                    release = li.a['href'].split('path=')[-1:][0][:-1]
+                    version = li.a['href'].split('path=')[-1:][0][:-1]
                 except TypeError:
-                    raise UnknownReleaseError('error: could not find release version')
+                    raise UnknownVersionError('error: could not find version')
                 else:
-                    self.__check_release(release)
-                    return release
+                    self.__check_version(version)
+                    return version
 
-    def stable_release_url(self) -> str:
-        """ Return the latest stable release url """
+    def stable_version_url(self) -> str:
+        """ Return the latest stable version url """
 
-        return self.release_url(self.__latest_release_version(self.__phases.stable))
+        return self.version_url(self.__latest_version_by_phase(self.__phases.stable))
 
-    def beta_release_url(self) -> str:
-        """ Return the latest beta release url """
+    def beta_version_url(self) -> str:
+        """ Return the latest beta version url """
 
-        return self.release_url(self.__latest_release_version(self.__phases.beta))
+        return self.version_url(self.__latest_version_by_phase(self.__phases.beta))
 
-    def release_url(self, release) -> str:
-        """ Return the release download url """
+    def version_url(self, version) -> str:
+        """ Return the version download url """
 
-        self.__check_release(release)
+        self.__check_version(version)
 
         arch = struct.calcsize('P') * 8
         arch_64 = 64
 
         if self.__platform == self.__platforms.win:
-
             # 64bit
             if arch == arch_64:
                 try:
-                    url = (constants.CHROMEDRIVER_STORAGE_URL + '/' + release + '/' + constants.CHROMEDRIVER + '_'
+                    url = (constants.CHROMEDRIVER_STORAGE_URL + '/' + version + '/' + constants.CHROMEDRIVER + '_'
                            + self.__platforms.win_64 + constants.ZIP_TYPE)
                     self.__check_url(url)
                     return url
-                except ReleaseUrlError:
+                except VersionUrlError:
                     pass
             # 32bit
-            url = (constants.CHROMEDRIVER_STORAGE_URL + '/' + release + '/' + constants.CHROMEDRIVER + '_'
+            url = (constants.CHROMEDRIVER_STORAGE_URL + '/' + version + '/' + constants.CHROMEDRIVER + '_'
                    + self.__platforms.win_32 + constants.ZIP_TYPE)
             self.__check_url(url)
             return url
 
         elif self.__platform == self.__platforms.linux:
-
             # 64bit
             if arch == arch_64:
                 try:
-                    url = (constants.CHROMEDRIVER_STORAGE_URL + '/' + release + '/' + constants.CHROMEDRIVER + '_'
+                    url = (constants.CHROMEDRIVER_STORAGE_URL + '/' + version + '/' + constants.CHROMEDRIVER + '_'
                            + self.__platforms.linux_64 + constants.ZIP_TYPE)
                     self.__check_url(url)
                     return url
-                except ReleaseUrlError:
+                except VersionUrlError:
                     pass
             # 32bit
-            url = (constants.CHROMEDRIVER_STORAGE_URL + '/' + release + '/' + constants.CHROMEDRIVER + '_'
+            url = (constants.CHROMEDRIVER_STORAGE_URL + '/' + version + '/' + constants.CHROMEDRIVER + '_'
                    + self.__platforms.linux_32 + constants.ZIP_TYPE)
             self.__check_url(url)
             return url
 
         elif self.__platform == self.__platforms.mac:
-
             # 64bit
             if arch == arch_64:
                 try:
-                    url = (constants.CHROMEDRIVER_STORAGE_URL + '/' + release + '/' + constants.CHROMEDRIVER + '_'
+                    url = (constants.CHROMEDRIVER_STORAGE_URL + '/' + version + '/' + constants.CHROMEDRIVER + '_'
                            + self.__platforms.mac_64 + constants.ZIP_TYPE)
                     self.__check_url(url)
                     return url
-                except ReleaseUrlError:
+                except VersionUrlError:
                     pass
             # 32bit
-            url = (constants.CHROMEDRIVER_STORAGE_URL + '/' + release + '/' + constants.CHROMEDRIVER + '_'
+            url = (constants.CHROMEDRIVER_STORAGE_URL + '/' + version + '/' + constants.CHROMEDRIVER + '_'
                    + self.__platforms.mac_32 + constants.ZIP_TYPE)
             self.__check_url(url)
             return url
 
-    def download_stable_release(self, output_path=None, extract=False) -> None:
-        """ Download the latest stable chromedriver release """
+    def download_stable_version(self, output_path=None, extract=False) -> None:
+        """ Download the latest stable chromedriver version """
 
-        release = self.__latest_release_version(self.__phases.stable)
-        self.download_release(release, output_path, extract)
+        version = self.__latest_version_by_phase(self.__phases.stable)
+        self.download_version(version, output_path, extract)
 
-    def download_beta_release(self, output_path=None, extract=False) -> None:
-        """ Download the latest stable chromedriver release """
+    def download_beta_version(self, output_path=None, extract=False) -> None:
+        """ Download the latest stable chromedriver version """
 
-        release = self.__latest_release_version(self.__phases.beta)
-        self.download_release(release, output_path, extract)
+        version = self.__latest_version_by_phase(self.__phases.beta)
+        self.download_version(version, output_path, extract)
 
-    def download_release(self, release, output_path=None, extract=False) -> str:
-        """ Download a chromedriver release """
+    def download_version(self, version, path=None, extract=False) -> str:
+        """ Download a chromedriver version """
 
-        self.__check_release(release)
+        self.__check_version(version)
 
-        if not output_path:
-            path = self._create_output_path_str(release)
-        else:
-            path = output_path
+        if len(str(path)) == 0:
+            # on path == '',
+            # ChromeDriver will be downloaded in the current dir
+            path = ''
+        elif not path:
+            # on path == None,
+            # ChromeDriver will be downloaded at e.g. chromedriver/88.0.4324.96/bin/chromedriver.exe
+            path = self._default_output_path(version)
 
-        # If the driver file already exists, return the dir path of the driver file
-        for root, dirs, files in os.walk(path):
-            for file in files:
-                if (file.lower() == constants.CHROMEDRIVER.lower() or
-                        file.lower() == constants.CHROMEDRIVER.lower() + '.exe'):
-                    return path
+        # on path == webdriver/bin (or any other dir name),
+        # ChromeDriver will be downloaded at webdriver/bin/chromedriver.exe
 
         def download(download_url, download_path) -> str:
             try:
                 output_path_with_file_name, file_name = retriever.download(url=download_url, output_path=download_path)
             except (OSError, HTTPError, RequestException) as err:
                 raise DownloadError(err)
-
             if extract:
                 with zipfile.ZipFile(output_path_with_file_name, 'r') as zip_ref:
                     zip_ref.extractall(path=download_path)
                 os.remove(output_path_with_file_name)
-
-                if pl.system() == 'Linux' or pl.system() == 'Darwin':
-                    os.chmod(path + '/' + constants.CHROMEDRIVER, 0o755)
-
-            return path
-
-        url = self.release_url(release)
+                if self.__platform == self.__platforms.linux or self.__platform == self.__platforms.mac:
+                    os.chmod(download_path + '/' + constants.CHROMEDRIVER, 0o755)
+            return download_path
 
         # Download the driver file and return the dir path of the driver file
+        url = self.version_url(version)
         return download(url, path)
 
     def __check_url(self, url) -> None:
         """ Check if url is valid """
 
         if requests.head(url).status_code != 200:
-            raise ReleaseUrlError('error: Invalid url')
+            raise VersionUrlError('error: Invalid url')
 
-    def __check_release(self, release) -> None:
-        """ Check if release format is valid """
+    def __check_version(self, version) -> None:
+        """ Check if version format is valid """
 
-        split_release = release.split('.')
-
-        for number in split_release:
+        split_version = version.split('.')
+        for number in split_version:
             if not number.isnumeric():
-                raise UnknownReleaseError('error: Invalid release format')
+                raise UnknownVersionError('error: Invalid version format')
 
     def __check_platform(self, platform) -> str:
         """ Check if platform is valid """
@@ -216,7 +208,6 @@ class GetChromeDriver:
         if platform not in self.__platforms.list:
             raise UnknownPlatformError('error: platform not recognized, choose a platform from: '
                                        + str(self.__platforms.list))
-
         return platform
 
     def matching_version(self):
@@ -232,14 +223,14 @@ class GetChromeDriver:
                 break
         return chromedriver_version_to_download
 
-    def auto_download(self, extract=False) -> str:
+    def auto_download(self, output_path=None, extract=False) -> str:
         """ Download ChromeDriver for the installed Chrome version on machine """
 
-        release = self.matching_version()
-        if release == '' or release is None:
+        version = self.matching_version()
+        if version == '' or version is None:
             raise VersionError('error: unable to find a ChromeDriver version for the installed Chrome version')
 
-        return self.download_release(release, extract=extract)
+        return self.download_version(version, output_path, extract)
 
     def install(self) -> None:
         """ Install ChromeDriver for the installed Chrome version on machine """
@@ -291,25 +282,25 @@ class GetChromeDriver:
     def __get_installed_chrome_version(self) -> str:
         """ Return the installed Chrome version on the machine """
 
-        if pl.system() == 'Windows':
+        if self.__platform == self.__platforms.win:
             process = subprocess.Popen(
                 ['reg', 'query', 'HKEY_CURRENT_USER\\SOFTWARE\\Google\\Chrome\\BLBeacon', '/v', 'version'],
                 stdout=subprocess.PIPE, stderr=subprocess.DEVNULL, stdin=subprocess.DEVNULL)
             return process.communicate()[0].decode('UTF-8').split()[-1]
 
-        elif pl.system() == 'Linux':
+        elif self.__platform == self.__platforms.linux:
             process = subprocess.Popen(
                 ['google-chrome', '--version'],
                 stdout=subprocess.PIPE, stderr=subprocess.DEVNULL, stdin=subprocess.DEVNULL)
             return process.communicate()[0].decode('UTF-8').split()[-1]
 
-        elif pl.system() == 'Darwin':
+        elif self.__platform == self.__platforms.mac:
             process = subprocess.Popen(
                 ['/Applications/Google Chrome.app/Contents/MacOS/Google Chrome', '--version'],
                 stdout=subprocess.PIPE, stderr=subprocess.DEVNULL, stdin=subprocess.DEVNULL)
             return process.communicate()[0].decode('UTF-8').split()[-1]
 
-    def _create_output_path_str(self, release) -> str:
+    def _default_output_path(self, version) -> str:
         """ Return the default output path """
 
-        return constants.CHROMEDRIVER + '/' + release + '/' + 'bin'
+        return constants.CHROMEDRIVER + '/' + version + '/' + 'bin'
