@@ -9,7 +9,7 @@ from bs4 import BeautifulSoup
 import requests
 from decouple import config
 
-from get_chrome_driver import GetChromeDriver
+from .. import GetChromeDriver
 from .. import constants
 from .. import __version__
 from ..platforms import Platforms
@@ -18,24 +18,24 @@ name = 'get-chrome-driver'
 
 platforms = Platforms()
 
-stable_release = config('STABLE_RELEASE')
-random_release = config('RANDOM_RELEASE')
+stable_version = config('STABLE_VERSION')
+random_version = config('RANDOM_VERSION')
 
 if pl.system() == 'Windows':
     file_name_zipped = 'chromedriver_win32.zip'
     file_name = 'chromedriver.exe'
-    stable_release_url = 'https://chromedriver.storage.googleapis.com/' + stable_release + '/' + file_name_zipped
-    random_release_url = 'https://chromedriver.storage.googleapis.com/' + random_release + '/' + file_name_zipped
+    stable_version_url = 'https://chromedriver.storage.googleapis.com/' + stable_version + '/' + file_name_zipped
+    random_version_url = 'https://chromedriver.storage.googleapis.com/' + random_version + '/' + file_name_zipped
 elif pl.system() == 'Linux':
     file_name_zipped = 'chromedriver_linux64.zip'
     file_name = 'chromedriver'
-    stable_release_url = 'https://chromedriver.storage.googleapis.com/' + stable_release + '/' + file_name_zipped
-    random_release_url = 'https://chromedriver.storage.googleapis.com/' + random_release + '/' + file_name_zipped
+    stable_version_url = 'https://chromedriver.storage.googleapis.com/' + stable_version + '/' + file_name_zipped
+    random_version_url = 'https://chromedriver.storage.googleapis.com/' + random_version + '/' + file_name_zipped
 elif pl.system() == 'Darwin':
     file_name_zipped = 'chromedriver_mac64.zip'
     file_name = 'chromedriver'
-    stable_release_url = 'https://chromedriver.storage.googleapis.com/' + stable_release + '/' + file_name_zipped
-    random_release_url = 'https://chromedriver.storage.googleapis.com/' + random_release + '/' + file_name_zipped
+    stable_version_url = 'https://chromedriver.storage.googleapis.com/' + stable_version + '/' + file_name_zipped
+    random_version_url = 'https://chromedriver.storage.googleapis.com/' + random_version + '/' + file_name_zipped
 
 # Change to the current test directory
 os.chdir(os.path.dirname(__file__))
@@ -44,34 +44,34 @@ os.chdir(os.path.dirname(__file__))
 class TestApp:
 
     ###################################
-    # LI TEXT "LATEST STABLE RELEASE" #
+    # LI TEXT "LATEST STABLE VERSION" #
     ###################################
     def test_text_match_latest_stable(self):
         match_found = False
 
         result = requests.get(constants.CHROMEDRIVER_CHROMIUM_URL)
         soup = BeautifulSoup(result.content, 'html.parser')
-        ul = soup.select_one(constants.UL_RELEASES_SELECTOR)
+        ul = soup.select_one(constants.UL_VERSIONS_SELECTOR)
         for li in ul:
             text = li.text.replace(u'\u00A0', ' ')
-            if text[:len(constants.LATEST_STABLE_RELEASE_STR)].lower() == constants.LATEST_STABLE_RELEASE_STR.lower():
+            if text[:len(constants.LATEST_STABLE_VERSION_STR)].lower() == constants.LATEST_STABLE_VERSION_STR.lower():
                 match_found = True
                 break
 
         assert match_found is True
 
     #################################
-    # LI TEXT "LATEST BETA RELEASE" #
+    # LI TEXT "LATEST BETA VERSION" #
     #################################
     def test_text_match_latest_beta(self):
         match_found = False
 
         result = requests.get(constants.CHROMEDRIVER_CHROMIUM_URL)
         soup = BeautifulSoup(result.content, 'html.parser')
-        ul = soup.select_one(constants.UL_RELEASES_SELECTOR)
+        ul = soup.select_one(constants.UL_VERSIONS_SELECTOR)
         for li in ul:
             text = li.text.replace(u'\u00A0', ' ')
-            if text[:len(constants.LATEST_BETA_RELEASE_STR)].lower() == constants.LATEST_BETA_RELEASE_STR.lower():
+            if text[:len(constants.LATEST_BETA_VERSION_STR)].lower() == constants.LATEST_BETA_VERSION_STR.lower():
                 match_found = True
                 break
 
@@ -80,29 +80,29 @@ class TestApp:
     ##################
     # STABLE VERSION #
     ##################
-    def test_stable_release_version(self):
+    def test_stable_version(self):
         out = subprocess.run(args=[name, '--stable-version'],
                              universal_newlines=True,
                              stdout=subprocess.PIPE)
         actual = out.stdout.split()[0]
-        assert stable_release == str(actual)
+        assert stable_version == str(actual)
 
     ######################
-    # RANDOM RELEASE URL #
+    # RANDOM VERSION URL #
     ######################
-    def test_random_release_url(self):
-        url = random_release_url
-        out = subprocess.run(args=[name, '--release-url', random_release],
+    def test_random_version_url(self):
+        url = random_version_url
+        out = subprocess.run(args=[name, '--version-url', random_version],
                              universal_newlines=True,
                              stdout=subprocess.PIPE)
         actual = out.stdout.split()[0]
         assert url, str(actual)
 
     ######################
-    # STABLE RELEASE URL #
+    # STABLE VERSION URL #
     ######################
-    def test_stable_release_url(self):
-        url = stable_release_url
+    def test_stable_version_url(self):
+        url = stable_version_url
         out = subprocess.run(args=[name, '--stable-url'],
                              universal_newlines=True,
                              stdout=subprocess.PIPE)
@@ -114,9 +114,9 @@ class TestApp:
     ##############################
     def test_auto_download_no_extract(self):
         get_driver = GetChromeDriver()
-        release = get_driver.matching_version()
+        version = get_driver.matching_version()
         subprocess.run(args=[name, '--auto-download'], stdout=subprocess.PIPE)
-        file_path = get_driver._create_output_path_str(release) + '/' + file_name_zipped
+        file_path = get_driver._default_output_path(version) + '/' + file_name_zipped
         result = path.exists(file_path)
         assert result
 
@@ -125,54 +125,54 @@ class TestApp:
     ###########################
     def test_auto_download_extract(self):
         get_driver = GetChromeDriver()
-        release = get_driver.matching_version()
+        version = get_driver.matching_version()
         subprocess.run(args=[name, '--auto-download', '--extract'], stdout=subprocess.PIPE)
-        file_path_extracted = get_driver._create_output_path_str(release) + '/' + file_name
+        file_path_extracted = get_driver._default_output_path(version) + '/' + file_name
         result = path.exists(file_path_extracted)
         assert result
 
     ########################################
-    # DOWNLOAD STABLE RELEASE - NO EXTRACT #
+    # DOWNLOAD STABLE VERSION - NO EXTRACT #
     ########################################
-    def test_download_stable_release_no_extract(self):
+    def test_download_stable_version_no_extract(self):
         get_driver = GetChromeDriver()
-        release = stable_release
+        version = stable_version
         subprocess.run(args=[name, '--download-stable'], stdout=subprocess.PIPE)
-        file_path = get_driver._create_output_path_str(release) + '/' + file_name_zipped
+        file_path = get_driver._default_output_path(version) + '/' + file_name_zipped
         result = path.exists(file_path)
         assert result
 
     #######################################
-    # DOWNLOAD STABLE RELEASE - EXTRACTED #
+    # DOWNLOAD STABLE VERSION - EXTRACTED #
     #######################################
-    def test_download_stable_release_extract(self):
+    def test_download_stable_version_extract(self):
         get_driver = GetChromeDriver()
-        release = stable_release
+        version = stable_version
         subprocess.run(args=[name, '--download-stable', '--extract'], stdout=subprocess.PIPE)
-        file_path_extracted = get_driver._create_output_path_str(release) + '/' + file_name
+        file_path_extracted = get_driver._default_output_path(version) + '/' + file_name
         result = path.exists(file_path_extracted)
         assert result
 
     ########################################
-    # DOWNLOAD RANDOM RELEASE - NO EXTRACT #
+    # DOWNLOAD RANDOM VERSION - NO EXTRACT #
     ########################################
-    def test_download_random_release_no_extract(self):
+    def test_download_random_version_no_extract(self):
         get_driver = GetChromeDriver()
-        release = random_release
-        subprocess.run(args=[name, '--download-release', release], stdout=subprocess.PIPE)
-        file_path = get_driver._create_output_path_str(release) + '/' + file_name_zipped
+        version = random_version
+        subprocess.run(args=[name, '--download-version', version], stdout=subprocess.PIPE)
+        file_path = get_driver._default_output_path(version) + '/' + file_name_zipped
         result = path.exists(file_path)
         assert result
 
     #######################################
-    # DOWNLOAD RANDOM RELEASE - EXTRACTED #
+    # DOWNLOAD RANDOM VERSION - EXTRACTED #
     #######################################
-    def test_download_random_release_extract(self):
+    def test_download_random_version_extract(self):
         get_driver = GetChromeDriver()
-        release = random_release
-        subprocess.run(args=[name, '--download-release', release, '--extract'],
+        version = random_version
+        subprocess.run(args=[name, '--download-version', version, '--extract'],
                        stdout=subprocess.PIPE)
-        file_path_extracted = get_driver._create_output_path_str(release) + '/' + file_name
+        file_path_extracted = get_driver._default_output_path(version) + '/' + file_name
         result = path.exists(file_path_extracted)
         assert result
 
